@@ -1,9 +1,8 @@
-/* -*- c-file-style: "java"; indent-tabs-mode: nil -*-
+/* -*- c-file-style: "java"; indent-tabs-mode: nil; fill-column: 78; -*-
  * 
  * distcc -- A simple distributed compiler system
- * $Header: /data/cvs/distcc/src/help.c,v 1.2 2002/05/17 04:10:50 mbp Exp $ 
  *
- * Copyright (C) 2002 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2002, 2003, 2004 by Martin Pool <mbp@samba.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,6 +20,10 @@
  * USA
  */
 
+                    /*
+                     * Tell me what you need, and I'll tell you how to 
+                     * get along without it.                -- Dilbert
+                     */
 
 /**
  * @file
@@ -28,11 +31,12 @@
  * Parse and apply server options.
  **/
 
+#include "config.h"
+
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include <assert.h>
 #include <string.h>
 #include <errno.h>
 
@@ -40,24 +44,39 @@
 #include "trace.h"
 
 
+int dcc_trace_version(void)
+{
+    rs_trace("%s %s %s; built %s %s",
+             rs_program_name, PACKAGE_VERSION, GNU_HOST,
+             __DATE__, __TIME__);
+    return 0;
+}
+
+
 int dcc_show_version(const char *prog)
 {
-    printf("%s %s  (protocol version %d)\n",
-           prog, VERSION, PROTO_VER);
+    /* The "built" message is the time this file was built, which may not be
+     * completely accurate for the program as a whole unless you do "make
+     * clean" */
+    printf("%s %s %s (protocols 1 and 2) (default port %d)\n"
+           "  built %s %s\n",
+           prog, PACKAGE_VERSION, GNU_HOST, DISTCC_DEFAULT_PORT,
+           __DATE__, __TIME__);
     return 0;
 }
 
 
 int dcc_show_copyright(void)
 {
-    printf("Copyright (C) 2002 by Martin Pool\n"
+    printf("Copyright (C) 2002, 2003, 2004 by Martin Pool\n"
            "\n"
 "distcc comes with ABSOLUTELY NO WARRANTY.  distcc is free software, and\n"
 "you may use, modify and redistribute it under the terms of the GNU \n"
 "General Public License version 2 or later.  For more information see\n"
-"the file named COPYING.\n"
+"the file named COPYING or <http://www.fsf.org/>.\n"
 "\n"
-"Please report bugs or features to <mbp@samba.org>.\n"
+"Please report bugs or features to <distcc@lists.samba.org>.  For more\n"
+"information, see <http://distcc.samba.org/>.\n"
 "\n"
            );
     return 0;
